@@ -1,9 +1,9 @@
 /***************************************************************************
                           klineal.cpp  -  description
                              -------------------
-    begin                : Fri Oct 13 2000
-    copyright            : (C) 2000 by Till Krech
-    email                : till@snafu.de
+    Begin                : Fri Oct 13 2000
+    Copyright            : 2000 by Till Krech
+    Email                : till@snafu.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,39 +15,37 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <iostream>
+#include "klineal.h"
+
+#include <QBitmap>
+#include <QBrush>
+#include <QPainter>
+#include <QMouseEvent>
+#include <QLabel>
+#include <QShortcut>
 
 #include <kconfig.h>
 #include <kcursor.h>
-#include <kdebug.h>
-#include <kglobal.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
-#include <kimageeffect.h>
+#include <khelpmenu.h>
 #include <klocale.h>
-#include <kmainwindow.h>
-#include <knotifyclient.h>
-#include <kpopupmenu.h>
-#include <kstandarddirs.h>
-#include <kwin.h>
-#include <kstdguiitem.h>
-
-#include <qbitmap.h>
-#include <qcursor.h>
-#include <qdialog.h>
-#include <qiconset.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qwhatsthis.h>
-
-#include "klineal.h"
+#include <knotification.h>
+#include <kwindowsystem.h>
+#include <KStandardGuiItem>
+#include <ktoolinvocation.h>
+#include <kfontdialog.h>
+#include <kmenu.h>
+#include <kdebug.h>
+#include <kapplication.h>
 
 #define CFG_KEY_BGCOLOR "BgColor"
 #define CFG_KEY_SCALE_FONT "ScaleFont"
 #define CFG_KEY_LENGTH "Length"
 #define CFG_GROUP_SETTINGS "StoredSettings"
 #define DEFAULT_RULER_COLOR QColor(255, 200, 80)
+#define FULLSCREENID 23
+
 /**
 * this is our cursor bitmap:
 * a line 48 pixels long with an arrow pointing down
@@ -66,109 +64,118 @@ static const uchar cursorBits[] = {
 * create the thingy with no borders and set up
 * its members
 */
-KLineal::KLineal(QWidget*parent,const char* name):KMainWindow(parent,name){
-	if (!name) {
-		name = "klineal";
-	}
-  KWin::setType(winId(), NET::Override);   // or NET::Normal
-  KWin::setState(winId(), NET::StaysOnTop);
-  setPaletteBackgroundColor(black);
-  QWhatsThis::add(this,
-  i18n(
-  	"This is a tool to measure pixel distances and colors on the screen. "
-  	"It is useful for working on layouts of dialogs, web pages etc."
-  ));
-  QBitmap bim = QBitmap(QSize(8, 48), cursorBits);
-  QWMatrix m;
+KLineal::KLineal(QWidget*parent):QWidget(parent),mColorSelector(this){
+  mLenMenu=0;
+  KWindowSystem::setType(winId(), NET::Override);   // or NET::Normal
+  KWindowSystem::setState(winId(), NET::KeepAbove);
+  this->setWhatsThis(
+  i18n("This is a tool to measure pixel distances and colors on the screen. "
+       "It is useful for working on layouts of dialogs, web pages etc."));
+  QBitmap bim = QBitmap::fromData(QSize(8, 48), cursorBits, QImage::Format_Mono);
+  QMatrix m;
   m.rotate(90.0);
   mNorthCursor = QCursor(bim, bim, 3, 47);
-  bim = bim.xForm(m);
+  bim = bim.transformed(m);
   mEastCursor = QCursor(bim, bim, 0, 3);
-  bim = bim.xForm(m);
+  bim = bim.transformed(m);
   mSouthCursor = QCursor(bim, bim, 4, 0);
-  bim = bim.xForm(m);
+  bim = bim.transformed(m);
   mWestCursor = QCursor(bim, bim, 47, 4);
 
   mCurrentCursor = mNorthCursor;
   setMinimumSize(60,60);
   setMaximumSize(8000,8000);
-  KConfig *cfg = kapp->config();
+  KSharedConfig::Ptr cfg = KGlobal::config();
   QColor defaultColor = DEFAULT_RULER_COLOR;
   QFont defaultFont(KGlobalSettings::generalFont().family(), 8);
   defaultFont.setPixelSize(8);
   if (cfg) {
-      cfg->setGroup(CFG_GROUP_SETTINGS);
-      mColor = cfg->readColorEntry(CFG_KEY_BGCOLOR, &defaultColor);
-      mScaleFont = cfg->readFontEntry(CFG_KEY_SCALE_FONT, &defaultFont);
-      mLongEdgeLen = cfg->readNumEntry(CFG_KEY_LENGTH, 600);
+      KConfigGroup cfgcg(cfg, CFG_GROUP_SETTINGS);
+      mColor = cfgcg.readEntry(CFG_KEY_BGCOLOR, defaultColor);
+      mScaleFont = cfgcg.readEntry(CFG_KEY_SCALE_FONT, defaultFont);
+      mLongEdgeLen = cfgcg.readEntry(CFG_KEY_LENGTH, 600);
     } else {
-  		mColor = defaultColor;
+      mColor = defaultColor;
       mScaleFont = defaultFont;
       mLongEdgeLen = 400;
   }
-  kdDebug() << "mLongEdgeLen=" << mLongEdgeLen << endl;
+  kDebug() << "mLongEdgeLen=" << mLongEdgeLen;
   mShortEdgeLen = 70;
 
   mLabel = new QLabel(this);
   mLabel->setGeometry(0,height()-12,32,12);
-  mLabel->setBackgroundOrigin(ParentOrigin);
   QFont labelFont(KGlobalSettings::generalFont().family(), 10);
   labelFont.setPixelSize(10);
   mLabel->setFont(labelFont);
-  QWhatsThis::add(mLabel,
-  	i18n(
-  		"This is the current distance measured in pixels."
-  	));
-	mColorLabel = new QLabel(this);
+  mLabel->setWhatsThis(i18n("This is the current distance measured in pixels."));
+  mColorLabel = new QLabel(this);
+  mColorLabel->setAutoFillBackground(true);
   mColorLabel->resize(45,12);
-  mColorLabel->setPaletteBackgroundColor(mColor);
   mColorLabel->hide();
   QFont colorFont(KGlobalSettings::fixedFont().family(), 10);
   colorFont.setPixelSize(10);
   mColorLabel->setFont(colorFont);
   mColorLabel->move(mLabel->pos() + QPoint(0, 20));
-  QWhatsThis::add(mColorLabel,
-  	i18n(
-  		"This is the current color in hexadecimal rgb representation as you may use it in HTML or as a QColor name. "
-  		"The rectangles background shows the color of the pixel inside the "
-  		"little square at the end of the line cursor."
-  	));
+  mColorLabel->setWhatsThis(i18n(
+        "This is the current color in hexadecimal rgb representation as you may use it in HTML or as a QColor name. "
+        "The rectangles background shows the color of the pixel inside the "
+        "little square at the end of the line cursor."));
 
   resize(QSize(mLongEdgeLen, mShortEdgeLen));
-  setMouseTracking(TRUE);
-  mDragging = FALSE;
+  setMouseTracking(true);
+  mDragging = false;
   mOrientation = South;
   _clicked = false;
   setOrientation(South);
   // setMediumLength();
-  mMenu = new KPopupMenu(this);
-  mMenu->insertTitle(i18n("KRuler"));
-  KPopupMenu *oriMenu = new KPopupMenu(this);
-  oriMenu->insertItem(UserIconSet("kruler-north"), i18n("&North"), this, SLOT(setNorth()), Key_N);
-  oriMenu->insertItem(UserIconSet("kruler-east"), i18n("&East"), this, SLOT(setEast()), Key_E);
-  oriMenu->insertItem(UserIconSet("kruler-south"), i18n("&South"), this, SLOT(setSouth()), Key_S);
-  oriMenu->insertItem(UserIconSet("kruler-west"), i18n("&West"), this, SLOT(setWest()), Key_W);
-  oriMenu->insertItem(i18n("&Turn Right"), this, SLOT(turnRight()), Key_R);
-  oriMenu->insertItem(i18n("Turn &Left"), this, SLOT(turnLeft()), Key_L);
-  mMenu->insertItem(i18n("&Orientation"), oriMenu);
-  KPopupMenu *lenMenu = new KPopupMenu(this);
-  lenMenu->insertItem(i18n("&Short"), this, SLOT(setShortLength()), CTRL+Key_S);
-  lenMenu->insertItem(i18n("&Medium"), this, SLOT(setMediumLength()), CTRL+Key_M);
-  lenMenu->insertItem(i18n("&Tall"), this, SLOT(setTallLength()), CTRL+Key_T);
-  lenMenu->insertItem(i18n("&Full Screen Width"), this, SLOT(setFullLength()), CTRL+Key_F);
-  mMenu->insertItem(i18n("&Length"), lenMenu);
-  mMenu->insertItem(i18n("&Choose Color..."), this, SLOT(choseColor()), CTRL+Key_C);
-  mMenu->insertItem(i18n("Choose &Font..."), this, SLOT(choseFont()), Key_F);
-  mMenu->insertSeparator();
-  mMenu->insertItem(SmallIcon( "help" ), KStdGuiItem::help().text(), helpMenu());
-  mMenu->insertSeparator();
-  mMenu->insertItem(SmallIcon( "exit" ), KStdGuiItem::quit().text(), kapp, SLOT(quit()), CTRL+Key_Q);
+  mMenu = new KMenu(this);
+  mMenu->addTitle(i18n("KRuler"));
+  KMenu *oriMenu = new KMenu(this);
+  oriMenu->addAction(KIcon("kruler-north"), i18nc("Turn Kruler North", "&North"), this, SLOT(setNorth()), Qt::Key_N);
+  oriMenu->addAction(KIcon("kruler-east"), i18nc("Turn Kruler East", "&East"), this, SLOT(setEast()), Qt::Key_E);
+  oriMenu->addAction(KIcon("kruler-south"), i18nc("Turn Kruler South", "&South"), this, SLOT(setSouth()), Qt::Key_S);
+  oriMenu->addAction(KIcon("kruler-west"), i18nc("Turn Kruler West", "&West"), this, SLOT(setWest()), Qt::Key_W);
+  oriMenu->addAction(KIcon("object-rotate-right"), i18n("&Turn Right"), this, SLOT(turnRight()), Qt::Key_R);
+  oriMenu->addAction(KIcon("object-rotate-left"), i18n("Turn &Left"), this, SLOT(turnLeft()), Qt::Key_L);
+  new QShortcut( Qt::Key_N, this, SLOT(setNorth()));
+  new QShortcut(Qt::Key_E,this,SLOT(setEast()));
+  new QShortcut(Qt::Key_S,this, SLOT(setSouth()));
+  new QShortcut(Qt::Key_W,this, SLOT(setWest()));
+  new QShortcut(Qt::Key_R,this, SLOT(turnRight()));
+  new QShortcut(Qt::Key_L,this, SLOT(turnLeft()));
+  oriMenu->setTitle(i18n("&Orientation"));
+  mMenu->addMenu(oriMenu);
+  mLenMenu = new KMenu(this);
+  mLenMenu->addAction(i18nc("Make Kruler Height Short", "&Short"), this, SLOT(setShortLength()), Qt::CTRL+Qt::Key_S);
+  mLenMenu->addAction(i18nc("Make Kruler Height Medium", "&Medium"), this, SLOT(setMediumLength()), Qt::CTRL+Qt::Key_M);
+  mLenMenu->addAction(i18nc("Make Kruler Height Tall", "&Tall"), this, SLOT(setTallLength()), Qt::CTRL+Qt::Key_T);
+  mFullScreenAction = mLenMenu->addAction(i18n("&Full Screen Width"), this, SLOT(setFullLength()), Qt::CTRL+Qt::Key_F);
+  new QShortcut(Qt::CTRL+Qt::Key_S,this, SLOT(setShortLength()));
+  new QShortcut(Qt::CTRL+Qt::Key_M,this, SLOT(setMediumLength()));
+  new QShortcut(Qt::CTRL+Qt::Key_T,this, SLOT(setTallLength()));
+  new QShortcut(Qt::CTRL+Qt::Key_F,this, SLOT(setFullLength()));
+  mLenMenu->setTitle(i18n("&Length"));
+  mMenu->addMenu(mLenMenu);
+  mMenu->addAction(KIcon("preferences-desktop-color"), i18n("&Choose Color..."), this, SLOT(choseColor()), Qt::CTRL+Qt::Key_C);
+  mMenu->addAction(KIcon("preferences-desktop-font"), i18n("Choose &Font..."), this, SLOT(choseFont()), Qt::Key_F);
+  new QShortcut(Qt::CTRL+Qt::Key_C,this, SLOT(choseColor()));
+  new QShortcut(Qt::Key_F,this, SLOT(choseFont()));
+  mMenu->addSeparator();
+  mMenu->addMenu((new KHelpMenu(this, KGlobal::mainComponent().aboutData(), true))->menu());
+  mMenu->addSeparator();
+  mMenu->addAction(KIcon("application-exit"), KStandardGuiItem::quit().text(), kapp, SLOT(quit()), Qt::CTRL+Qt::Key_Q);
+  new QShortcut(Qt::CTRL+Qt::Key_Q,this, SLOT(slotQuit()));
   mLastClickPos = geometry().topLeft()+QPoint(width()/2, height()/2);
 }
 
 KLineal::~KLineal(){
 }
 
+void KLineal::slotQuit()
+{
+   kapp->quit();
+}
+
 void KLineal::move(int x, int y) {
   move(QPoint(x, y));
 }
@@ -188,7 +195,7 @@ int KLineal::y() {
   return pos().y();
 }
 
-static void rotateRect(QRect &r, QPoint center, int nineties) {
+static void rotateRect(QRect &r, const QPoint &center, int nineties) {
   static int sintab[4] = {0,1,0,-1};
   static int costab[4] = {1,0,-1,0};
   int i=0;
@@ -197,46 +204,45 @@ static void rotateRect(QRect &r, QPoint center, int nineties) {
     nineties = -nineties+4;
   }
   i = nineties % 4;
-  r.moveBy(-center.x(), -center.y());
-  r.coords(&x1, &y1, &x2, &y2);
+  r.translate(-center.x(), -center.y());
+  r.getCoords(&x1, &y1, &x2, &y2);
   r.setCoords(
-	      x1 * costab[i] + y1 * sintab[i],
-	      -x1 * sintab[i] + y1 * costab[i],
-	      x2 * costab[i] + y2 * sintab[i],
-	      -x2 * sintab[i] + y2 * costab[i]
-	      );
-  r = r.normalize();
-  r.moveBy(center.x(), center.y());
+            x1 * costab[i] + y1 * sintab[i],
+            -x1 * sintab[i] + y1 * costab[i],
+            x2 * costab[i] + y2 * sintab[i],
+            -x2 * sintab[i] + y2 * costab[i]);
+  r = r.normalized();
+  r.translate(center.x(), center.y());
 }
 
-void KLineal::setupBackground() {
+void KLineal::drawBackground(QPainter& painter) {
   QColor a, b, bg = mColor;
-  KImageEffect::GradientType gradType = KImageEffect::HorizontalGradient;
+  QLinearGradient gradient;
   switch (mOrientation) {
     case North:
       a = bg.light(120);
       b = bg.dark(130);
-      gradType = KImageEffect::VerticalGradient;
+      gradient = QLinearGradient(1, 0, 1, height());
       break;
     case South:
       b = bg.light(120);
       a = bg.dark(130);
-      gradType = KImageEffect::VerticalGradient;
+      gradient = QLinearGradient(1, 0, 1, height());
       break;
     case West:
       a = bg.light(120);
       b = bg.dark(130);
-      gradType = KImageEffect::HorizontalGradient;
+      gradient = QLinearGradient(0, 1, width(), 1);
       break;
     case East:
       b = bg.light(120);
       a = bg.dark(130);
-      gradType = KImageEffect::HorizontalGradient;
+      gradient = QLinearGradient(0, 1, width(), 1);
       break;
   }
-  QPixmap bgPixmap = QPixmap(KImageEffect::gradient(size(), a, b, gradType));
-  setErasePixmap(bgPixmap);
-  mLabel->setErasePixmap(bgPixmap);
+  gradient.setColorAt(0, a);
+  gradient.setColorAt(1, b);
+  painter.fillRect(rect(), QBrush(gradient));
 }
 
 void KLineal::setOrientation(int inOrientation) {
@@ -252,6 +258,17 @@ void KLineal::setOrientation(int inOrientation) {
    }
 
   rotateRect(r, center, nineties);
+
+  QRect desktop = KGlobalSettings::desktopGeometry(this);
+  if (r.top() < desktop.top())
+     r.moveTop( desktop.top() );
+  if (r.bottom() > desktop.bottom())
+     r.moveBottom( desktop.bottom() );
+  if (r.left() < desktop.left())
+     r.moveLeft( desktop.left() );
+  if (r.right() > desktop.right())
+     r.moveRight( desktop.right() );
+
   setGeometry(r);
   mOrientation = (inOrientation + 4) % 4;
   switch(mOrientation) {
@@ -276,8 +293,11 @@ void KLineal::setOrientation(int inOrientation) {
     mCurrentCursor = mWestCursor;
     break;
   }
+  if (mLenMenu) {
+    if (mFullScreenAction)
+        mFullScreenAction->setText(mOrientation % 2 ? i18n("&Full Screen Height") : i18n("&Full Screen Width"));
+  }
   setCursor(mCurrentCursor);
-  setupBackground();
   repaint();
 }
 void KLineal::setNorth() {
@@ -347,10 +367,7 @@ void KLineal::choseColor() {
   mColorSelector.setDefaultColor( DEFAULT_RULER_COLOR );
   mColorSelector.show();
 
-  connect(&mColorSelector, SIGNAL(okClicked()), this, SLOT(setColor()));
-  connect(&mColorSelector, SIGNAL(yesClicked()), this, SLOT(setColor()));
   connect(&mColorSelector, SIGNAL(closeClicked()), this, SLOT(setColor()));
-  connect(&mColorSelector, SIGNAL(defaultClicked()), this, SLOT(setColor()));
   connect(&mColorSelector, SIGNAL(colorSelected(const QColor&)), this, SLOT(setColor(const QColor&)));
 	/*
   connect(&mColorSelector, SIGNAL(cancelPressed()), this, SLOT(restoreColor()));
@@ -394,20 +411,21 @@ void KLineal::setColor(const QColor &color) {
   mColor = color;
   if ( !mColor.isValid() )
     mColor = DEFAULT_RULER_COLOR;
-  setupBackground();
+
+  repaint();
 }
 
 /**
 * save the ruler color to the config file
 */
 void KLineal::saveSettings() {
-  KConfig *cfg = kapp->config(); // new KConfig(locateLocal("config", kapp->name()+"rc"));
+  KSharedConfig::Ptr cfg = KGlobal::config(); // new KConfig(locateLocal("config", kapp->name()+"rc"));
   if (cfg) {
       QColor color = mColor;
-      cfg->setGroup(CFG_GROUP_SETTINGS);
-    	cfg->writeEntry(QString(CFG_KEY_BGCOLOR), color);
-    	cfg->writeEntry(QString(CFG_KEY_SCALE_FONT), mScaleFont);
-    	cfg->writeEntry(QString(CFG_KEY_LENGTH), mLongEdgeLen);
+      KConfigGroup cfgcg(cfg, CFG_GROUP_SETTINGS);
+      cfgcg.writeEntry(QString(CFG_KEY_BGCOLOR), color);
+      cfgcg.writeEntry(QString(CFG_KEY_SCALE_FONT), mScaleFont);
+      cfgcg.writeEntry(QString(CFG_KEY_LENGTH), mLongEdgeLen);
       cfg->sync();
   }
 }
@@ -422,8 +440,8 @@ void KLineal::restoreColor() {
 * lets the context menu appear at current cursor position
 */
 void KLineal::showMenu() {
-	QPoint pos = QCursor::pos();
-	mMenu->popup(pos);
+  QPoint pos = QCursor::pos();
+  mMenu->popup(pos);
 }
 
 /**
@@ -478,71 +496,71 @@ void KLineal::adjustLabel() {
   mLabel->setText(s);
 }
 void KLineal::keyPressEvent(QKeyEvent *e) {
-	QPoint dist(0,0);
-	switch (e->key()) {
-	case Key_F1:
-    	kapp->invokeHelp();
- 			break;
-  	case Key_Left:
-    	dist.setX(-1);
- 			break;
-  	case Key_Right:
-    	dist.setX(1);
- 			break;
-  	case Key_Up:
-    	dist.setY(-1);
- 			break;
-  	case Key_Down:
-    	dist.setY(1);
- 			break;
-  	default:
-    	KMainWindow::keyPressEvent(e);
-      return;
- 	}
-	if (e->state() & ShiftButton) {
-  	dist *= 10;
+  QPoint dist(0,0);
+  switch (e->key()) {
+  case Qt::Key_F1:
+    KToolInvocation::invokeHelp();
+    break;
+  case Qt::Key_Left:
+    dist.setX(-1);
+    break;
+  case Qt::Key_Right:
+    dist.setX(1);
+    break;
+  case Qt::Key_Up:
+    dist.setY(-1);
+    break;
+  case Qt::Key_Down:
+    dist.setY(1);
+    break;
+  default:
+    QWidget::keyPressEvent(e);
+    return;
+  }
+  if (e->modifiers() & Qt::ShiftModifier) {
+    dist *= 10;
   }
   move(pos()+dist);
-  KNotifyClient::event(0, "cursormove",  QString::null);
+  KNotification::event(0, "cursormove",  QString());
 }
 /**
-* overwritten to handle the line cursor which is a seperate widget outside the main
+* overwritten to handle the line cursor which is a separate widget outside the main
 * window. Also used for dragging.
 */
 void KLineal::mouseMoveEvent(QMouseEvent * /*inEvent*/) {
   if (mDragging && this == mouseGrabber()) {
     move(QCursor::pos() - mDragOffset);
   } else {
-  	QPoint p = QCursor::pos();
-  	switch (mOrientation) {
+  QPoint p = QCursor::pos();
+  switch (mOrientation) {
     case North:
-    	p.setY(p.y()-46);
-      break;
+        p.setY(p.y()-46);
+        break;
     case East:
-    	p.setX(p.x()+46);
-      break;
+        p.setX(p.x()+46);
+        break;
     case West:
-    	p.setX(p.x()-46);
-      break;
+        p.setX(p.x()-46);
+        break;
     case South:
-    	p.setY(p.y()+46);
-    	break;
+        p.setY(p.y()+46);
+        break;
     }
     // cerr << p.x()-x() << "," << p.y()-y() << ": " << KColorDialog::grabColor(p).name() << endl;
     QColor color = KColorDialog::grabColor(p);
     int h, s, v;
-    color.hsv(&h, &s, &v);
- 		mColorLabel->setText(color.name().upper());
-  	mColorLabel->setPaletteBackgroundColor(color);
-  	if (v < 255/2) {
-  		v = 255;
-  	} else {
-  		v = 0;
-   	}
-   	color.setHsv(h, s, v);
-  	QPalette palette = mColorLabel->palette();
-  	palette.setColor(QColorGroup::Foreground, color);
-  	mColorLabel->setPalette(palette);
+    color.getHsv(&h, &s, &v);
+    mColorLabel->setText(color.name().toUpper());
+    QPalette palette = mColorLabel->palette();
+    palette.setColor(mColorLabel->backgroundRole(), color);
+    if (v < 255/2) {
+        v = 255;
+    } else {
+        v = 0;
+    }
+    color.setHsv(h, s, v);
+    palette.setColor(mColorLabel->foregroundRole(), color);
+    mColorLabel->setPalette(palette);
     adjustLabel();
   }
 }
@@ -556,15 +574,15 @@ void KLineal::mousePressEvent(QMouseEvent *inEvent) {
 
   QRect gr = geometry();
   mDragOffset = mLastClickPos - QPoint(gr.left(), gr.top());
-  if (inEvent->button() == LeftButton) {
+  if (inEvent->button() == Qt::LeftButton) {
     if (!mDragging) {
-      grabMouse(KCursor::handCursor());
-      mDragging = TRUE;
+      grabMouse(Qt::SizeAllCursor);
+      mDragging = true;
     }
-  } else if (inEvent->button() == MidButton) {
-		_clicked = true;
+  } else if (inEvent->button() == Qt::MidButton) {
+    _clicked = true;
     turnLeft();
-  } else if (inEvent->button() == RightButton) {
+  } else if (inEvent->button() == Qt::RightButton) {
     showMenu();
   }
 }
@@ -573,7 +591,7 @@ void KLineal::mousePressEvent(QMouseEvent *inEvent) {
 */
 void KLineal::mouseReleaseEvent(QMouseEvent * /*inEvent*/) {
   if (mDragging) {
-    mDragging = FALSE;
+    mDragging = false;
     releaseMouse();
   }
   showLabel();
@@ -582,7 +600,7 @@ void KLineal::mouseReleaseEvent(QMouseEvent * /*inEvent*/) {
 * draws the scale according to the orientation
 */
 void KLineal::drawScale(QPainter &painter) {
-  painter.setPen(black);
+  painter.setPen(Qt::black);
   QFont font = mScaleFont;
   // font.setPixelSize(9);
   painter.setFont(font);
@@ -641,55 +659,55 @@ void KLineal::drawScale(QPainter &painter) {
           painter.setFont(font);
           len = 18;
         } else {
-      	  len = 15;
+          len = 15;
         }
-      	QString units;
+        QString units;
         int digits;
         if (hundred == 100 || mOrientation == West || mOrientation == East) {
           digits = longCoo;
         } else {
           digits = longCoo % 100;
         }
-      	units.sprintf("%d", digits);
-      	QSize textSize = metrics.size(SingleLine, units);
+        units.sprintf("%d", digits);
+        QSize textSize = metrics.size(Qt::TextSingleLine, units);
         int tw = textSize.width();
         int th = textSize.height();
-       	switch (mOrientation) {
-       	case North:
+        switch (mOrientation) {
+        case North:
            if (digits < 1000  || fourty == 40 || hundred == 100) {
             if (longCoo != 0) {
-       	      painter.drawText(longCoo - tw/2, shortStart + len + th, units);
+                painter.drawText(longCoo - tw/2, shortStart + len + th, units);
             } else {
-              painter.drawText(1, shortStart + len + th, units);
+                painter.drawText(1, shortStart + len + th, units);
             }
            }
-       	  break;
-       	case South:
+        break;
+        case South:
            if (digits < 1000  || fourty == 40 || hundred == 100) {
             if (longCoo != 0) {
-       	      painter.drawText(longCoo - tw/2, shortStart - len - 2, units);
+                painter.drawText(longCoo - tw/2, shortStart - len - 2, units);
             } else {
-       	      painter.drawText(1, shortStart - len - 2, units);
+                painter.drawText(1, shortStart - len - 2, units);
             }
            }
-       	  break;
-       	case East:
+        break;
+        case East:
           if (longCoo != 0) {
-       	    painter.drawText(shortStart - len - tw - 2, longCoo + th/2 - 2, units);
+            painter.drawText(shortStart - len - tw - 2, longCoo + th/2 - 2, units);
           } else {
-       	    painter.drawText(shortStart - len - tw - 2, th-2, units);
+            painter.drawText(shortStart - len - tw - 2, th-2, units);
           }
-       	  break;
-       	case West:
+        break;
+        case West:
           if (longCoo != 0) {
-       	    painter.drawText(shortStart + len + 2, longCoo + th/2 - 2, units);
+            painter.drawText(shortStart + len + 2, longCoo + th/2 - 2, units);
           } else {
-       	    painter.drawText(shortStart + len + 2, th-2, units);
+            painter.drawText(shortStart + len + 2, th-2, units);
           }
-       	  break;
-       	}
+        break;
+        }
       } else {
-       	len = 10;
+        len = 10;
       }
     }
     switch(mOrientation) {
@@ -724,6 +742,7 @@ void KLineal::drawScale(QPainter &painter) {
 void KLineal::paintEvent(QPaintEvent * /*inEvent*/) {
   QPainter painter;
   painter.begin(this);
+  drawBackground(painter);
   drawScale(painter);
   painter.end();
 }
